<?php

namespace domain\PointSale\SharedPointSale;

use domain\_\AbstractResolver;
use domain\PointSale\PointSale\PointSale;
use domain\PointSale\PointSale\PointSaleRepository;

class SharedPointSaleResolver extends AbstractResolver
{
    protected PointSaleRepository $pointSaleRepository;
    protected SharedPointSaleRepository $sharedPointSaleRepository;

    public function loadDependencies(): void
    {
        $this->pointSaleRepository = $this->loadService(PointSaleRepository::class);
        $this->sharedPointSaleRepository = $this->loadService(SharedPointSaleRepository::class);
    }

    public function getPointsSaleSharedWithPointSale(PointSale $pointSale): array
    {
        $pointsSaleSharedWithPointSaleArray = [];
        $sharedPointsSaleConfirmedArray = $this->sharedPointSaleRepository->findSharedPointsSaleConfirmedByPointSale($pointSale);

        foreach($sharedPointsSaleConfirmedArray as $sharedPointSaleConfirmed) {
            if($sharedPointSaleConfirmed->getPointSale()->id != $pointSale->id
                && !in_array($sharedPointSaleConfirmed->getPointSale(), $pointsSaleSharedWithPointSaleArray)) {
                $pointsSaleSharedWithPointSaleArray[] = $sharedPointSaleConfirmed->getPointSale();
            }
            if($sharedPointSaleConfirmed->getPointSaleWithSharing()->id != $pointSale->id
                && !in_array($sharedPointSaleConfirmed->getPointSaleWithSharing(), $pointsSaleSharedWithPointSaleArray)) {
                $pointsSaleSharedWithPointSaleArray[] = $sharedPointSaleConfirmed->getPointSaleWithSharing();
            }
        }

        return $pointsSaleSharedWithPointSaleArray;
    }

    public function hasPointSaleSharedWithPointSale(PointSale $pointSale): bool
    {
        return (bool) count($this->getPointsSaleSharedWithPointSale($pointSale));
    }

    public function countPointsSaleShared(): int
    {
        $count = 0;
        $pointsSaleArray = $this->pointSaleRepository->findPointSales();

        foreach($pointsSaleArray as $pointSale) {
            if($this->hasPointSaleSharedWithPointSale($pointSale)) {
                $count ++;
            }
        }

        return $count;
    }

    public function countSharedPointsSaleRequestsOthers(): int
    {
        return count($this->sharedPointSaleRepository->findSharedPointsSaleRequestsOthers());
    }
}